@@ -1,6 +1,7 @@
 import act
 import xarray as xr
 import numpy as np
+import pandas as pd
 from datetime import datetime
 
 
@@ -53,6 +54,33 @@ def test_add_in_nan():
     assert(time_filled[5].values == time_answer[5])
 
 
+def test_get_missing_value():
+    obj = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_EBBR1)
+    missing = act.utils.data_utils.get_missing_value(obj, 'lv_e', use_FillValue=True)
+    assert missing == -9999
+
+
+def test_convert_units():
+    obj = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_EBBR1)
+    data = obj['soil_temp_1'].values
+    in_units = obj['soil_temp_1'].attrs['units']
+    r_data = act.utils.data_utils.convert_units(data, in_units, 'K')
+    assert np.ceil(r_data[0]) == 285
+
+    data = act.utils.data_utils.convert_units(r_data, 'K', 'C')
+    assert np.ceil(data[0]) == 12
+
+
+def test_ts_weighted_average():
+    obj = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_MET_WILDCARD)
+    cf_ds = {'sgpmetE13.b1': {'variable': ['tbrg_precip_total', 'org_precip_rate_mean',
+                                           'pwd_precip_rate_mean_1min'],
+                              'weight': [0.8, 0.15, 0.05], 'object': obj}}
+    data = act.utils.data_utils.ts_weighted_average(cf_ds)
+
+    np.testing.assert_almost_equal(np.sum(data), 84.9, decimal=1)
+
+
 def test_accum_precip():
     obj = act.io.armfiles.read_netcdf(
         act.tests.sample_files.EXAMPLE_MET_WILDCARD)
@@ -76,6 +104,11 @@ def test_calc_cog_sog():
     np.testing.assert_almost_equal(cog[10], 170.987, decimal=3)
     np.testing.assert_almost_equal(sog[15], 0.448, decimal=3)
 
+    obj = obj.rename({'lat': 'latitude', 'lon': 'longitude'})
+    obj = act.utils.calc_cog_sog(obj)
+    np.testing.assert_almost_equal(cog[10], 170.987, decimal=3)
+    np.testing.assert_almost_equal(sog[15], 0.448, decimal=3)
+
 
 def test_destination_azimuth_distance():
     lat = 37.1509
@@ -98,12 +131,16 @@ def test_calculate_dqr_times():
     ebbr2_result = act.utils.calculate_dqr_times(
         ebbr2_ds, variable=['rh_bottom_fraction'],
         qc_bit=3, threshold=2)
-
+    ebbr3_result = act.utils.calculate_dqr_times(
+        ebbr2_ds, variable=['rh_bottom_fraction'],
+        qc_bit=3)
     brs_result = act.utils.calculate_dqr_times(
         brs_ds, variable='down_short_hemisp_min', qc_bit=2, threshold=30)
     assert ebbr1_result == [('2019-11-25 02:00:00', '2019-11-25 04:30:00')]
     assert ebbr2_result == [('2019-11-30 00:00:00', '2019-11-30 11:00:00')]
     assert brs_result == [('2019-07-05 01:57:00', '2019-07-05 11:07:00')]
+    assert ebbr3_result is None
+
     ebbr1_ds.close()
     ebbr2_ds.close()
     brs_ds.close()
@@ -119,6 +156,10 @@ def test_decode_present_weather():
     assert data[100] == result
     assert data[600] == result
 
+    np.testing.assert_raises(ValueError, act.utils.inst_utils.decode_present_weather, obj)
+    np.testing.assert_raises(ValueError, act.utils.inst_utils.decode_present_weather,
+                             obj, variable='temp_temp')
+
 
 def test_datetime64_to_datetime():
     time_datetime = [datetime(2019, 1, 1, 1, 0),
@@ -169,3 +210,31 @@ def test_add_solar_variable():
     obj = act.io.armfiles.read_netcdf(act.tests.EXAMPLE_MET1)
     new_obj = act.utils.geo_utils.add_solar_variable(obj, dawn_dusk=True)
     assert np.sum(new_obj['sun_variable'].values) >= 582
+
+    obj = act.io.armfiles.read_netcdf(act.tests.EXAMPLE_IRTSST)
+    obj = obj.fillna(0)
+    new_obj = act.utils.geo_utils.add_solar_variable(obj)
+    assert np.sum(new_obj['sun_variable'].values) >= 12
+
+
+def test_reduce_time_ranges():
+    time = pd.date_range(start='2020-01-01T00:00:00', freq='1min', periods=100)
+    time = time.to_list()
+    time = time[0:50] + time[60:]
+    result = act.utils.datetime_utils.reduce_time_ranges(time)
+    assert len(result) == 2
+    assert result[1][1].minute == 39
+
+    result = act.utils.datetime_utils.reduce_time_ranges(time, broken_barh=True)
+    assert len(result) == 2
+
+
+def test_planck_converter():
+    wnum = 1100
+    temp = 300
+    radiance = 81.5
+    result = act.utils.radiance_utils.planck_converter(wnum=wnum, temperature=temp)
+    np.testing.assert_almost_equal(result, radiance, decimal=1)
+    result = act.utils.radiance_utils.planck_converter(wnum=wnum, radiance=radiance)
+    assert np.ceil(result) == temp
+    np.testing.assert_raises(ValueError, act.utils.radiance_utils.planck_converter)
