@@ -13,10 +13,12 @@ Community Toolkit.
 
     accumulate_precip
     add_in_nan
+    add_solar_variable
     assign_coordinates
     calc_cog_sog
     calculate_dqr_times
     convert_units
+    create_pyart_obj
     dates_between
     datetime64_to_datetime
     decode_present_weather
@@ -35,6 +37,7 @@ from .data_utils import convert_units
 from .data_utils import assign_coordinates
 from .data_utils import accumulate_precip
 from .data_utils import ts_weighted_average
+from .data_utils import create_pyart_obj
 from .datetime_utils import dates_between
 from .datetime_utils import numpy_to_arm_date
 from .datetime_utils import reduce_time_ranges
@@ -43,5 +46,6 @@ from .datetime_utils import datetime64_to_datetime
 from .qc_utils import calculate_dqr_times
 from .ship_utils import calc_cog_sog
 from .geo_utils import destination_azimuth_distance
+from .geo_utils import add_solar_variable
 from .inst_utils import decode_present_weather
 from .radiance_utils import planck_converter
